@@ -6,6 +6,7 @@ import os
 import os.path
 from textwrap import dedent
 import re
+import json
 from jinja2 import Environment, PackageLoader
 import urllib
 
@@ -17,6 +18,7 @@ TEMPLATE_LOADER = PackageLoader(__package__)
 TEMPLATE_ENV = Environment(
     loader=TEMPLATE_LOADER, trim_blocks=True
 )
+TEMPLATE_ENV.filters["tojson"] = json.dumps
 
 
 class SuiteDescriptionError(Exception):
@@ -41,7 +43,7 @@ class SuiteDescription(object):
     ]
 
     # Supported test runners
-    TEST_RUNNERS = ['jasmine']
+    TEST_RUNNERS = ['jasmine', 'jasmine_requirejs']
 
     def __init__(self, file_handle, root_dir):
         """
@@ -192,6 +194,22 @@ class SuiteDescription(object):
         else:
             return []
 
+    def requirejs_path_map(self):
+        """
+        Returns a map of aliases to paths, used by requirejs in loading files.
+        """
+        if not "requirejs" in self._desc_dict:
+            return {}
+        return self._desc_dict["requirejs"].get("paths", {})
+
+    def requirejs_baseUrl(self):
+        """
+        Returns a baseUrl to be appended onto the default requirejs baseUrl.
+        """
+        if not "requirejs" in self._desc_dict:
+            return ""
+        return self._desc_dict["requirejs"].get("baseUrl", "")
+
     def test_runner(self):
         """
         Return the name of the test runner to use (e.g. "Jasmine")
@@ -236,9 +254,10 @@ class SuiteDescription(object):
         If `enable_warnings` is true, then log a warning whenever
         we can't find a file we expect.
         """
-        paths = self._file_paths(path_list,
-                                 enable_warnings,
-                                 include_func=self._is_js_file) 
+        paths = self._file_paths(
+            path_list, enable_warnings,
+            include_func=self._is_js_file
+        )
         if only_in_page:
             return filter(self._include_in_page, paths)
         else:
@@ -471,7 +490,10 @@ class SuiteRenderer(object):
 
     # Dictionary mapping test runner names (e.g. 'jasmine') to
     # templates used to render the test runner page.
-    TEMPLATE_DICT = {'jasmine': 'jasmine_test_runner.html'}
+    TEMPLATE_DICT = {
+        'jasmine': 'jasmine_test_runner.html',
+        'jasmine_requirejs': 'jasmine_requirejs_test_runner.html',
+    }
 
     # The CSS ID of the <div> that will contain the output test results
     RESULTS_DIV_ID = 'js_test_tool_results'
@@ -511,13 +533,17 @@ class SuiteRenderer(object):
             raise SuiteRendererError(msg)
 
         # Create the context for the template
-        template_context = {'suite_name': suite_name,
-                            'lib_path_list': suite_desc.lib_paths(only_in_page=True),
-                            'src_path_list': suite_desc.src_paths(only_in_page=True),
-                            'spec_path_list': suite_desc.spec_paths(only_in_page=True),
-                            'results_div_id': self.RESULTS_DIV_ID,
-                            'error_div_id': self.ERROR_DIV_ID,
-                            'dev_mode': self._dev_mode}
+        template_context = {
+            'suite_name': suite_name,
+            'lib_path_list': suite_desc.lib_paths(only_in_page=True),
+            'src_path_list': suite_desc.src_paths(only_in_page=True),
+            'spec_path_list': suite_desc.spec_paths(only_in_page=True),
+            'requirejs_path_map': suite_desc.requirejs_path_map(),
+            'requirejs_baseUrl': suite_desc.requirejs_baseUrl(),
+            'results_div_id': self.RESULTS_DIV_ID,
+            'error_div_id': self.ERROR_DIV_ID,
+            'dev_mode': self._dev_mode,
+        }
 
         # Render the template
         try:
